# Deployment scripts

This directory will host charts, k8s, ansible and terraform scripts.

The charts will be published here:

https://github.com/orgs/IBM/packages/container/package/mcp-context-forge%2Fmcp-stack
